===================================
Welcome to the new Pootle 2.5.1-rc1
===================================

*Released on 1 December 2013*

We almost missed our :ref:`6 month release cycle <release-process_principles>`!
Many changes have gone into Pootle 2.5.1 which follows on from 2.5.0 released
in May.

Pootle 2.5.1 has been in production for a number of users, so although it is a
new official release, we've had many people running their production Pootle
server off this code.  This includes `Mozilla
<http://mozilla.locamotion.org/>`_ and `Evernote
<http://translate.evernote.com/pootle/>`_. So you are in good company.

For those who can't wait you might be interested to know what we've got planned
on our :ref:`roadmap <roadmap>` for Pootle 2.5.2.

Changes in Requirements
=======================
- Django >= 1.4.10
- `Translate Toolkit <http://toolkit.translatehouse.org/download.html>`_ >=
  1.11.0-rc1
- Python >= 2.6

Installation and Upgrade
========================
- :doc:`Installation </server/installation>`
- :doc:`Upgrade </server/upgrading>`

Major Changes
=============

These are by no means exhaustive, check the `git log
<https://github.com/translate/pootle/compare/stable%2F2.5.0...2.5.1-rc1>`_
for more details.

- :doc:`Tags </features/tags>` -- You can now tag and filter translation
  projects, making it easy to focus on a set of languages.
- :doc:`Goals </features/goals>` -- you can now group files within a project to
  ensure that translators focus on the most important tasks first.
- :doc:`Extension Actions </features/actions>` -- you can create custom actions
  using Python scripts. These are displayed with current actions and allow you
  to extend Pootle's functionality.
- :doc:`API </api/index>` -- an initial Pootle API is in place (disabled by
  default).


Important server admin changes
------------------------------
- Pootle now uses South to manage database upgrades.  A single command replaces
  the various command used previously and the automatic update has been
  removed.
- Fabric deployment scripts have been improved to make deployment easier.
- Security fixes identified by a Mozilla security audit have been implemented.
- Optimisations of asset caching such as Expires headers have been enabled.
- Various LDAP fixes.
- Static pages can now be used to track the acceptance of terms of use.


Visual Changes
--------------
- User contribution are displayed in the users profile page.
- Breadcrumbs now follow the way a translator would interact with Pootle and
  are unified across all vies of the project.
- Global search allows you to search across all projects and all languages.
- Last activity messages show quickly what last change was made to the
  translations.
- The export view allows for easier proofreading by translators.
- Various RTL fixes.


...and lots of refactoring, upgrades of upstream code, cleanups to remove
Django 1.3 specifics, missing documentation and of course, loads of bugs were
fixed

Credits
=======
The following people have made Pootle 2.5.1 possible:

Julen Ruiz Aizpuru, Leandro Regueiro, Dwayne Bailey, Alexander Dupuy, Khaled
Hosny, Arky, Fabio Pirola, Christian Hitz, Taras Semenenko, Chris Oelmueller,
Peter Bengtsson, Yasunori Mahata, Denis Parchenko, Henrik Saari, Hakan
Bayindir, Edmund Huber, Dmitry Rozhkov & Darío Hereñú
